require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dfsnamespacefolder',
  dscmeta_resource_friendly_name: 'DFSNamespaceFolder',
  dscmeta_resource_name: 'DSC_DFSNamespaceFolder',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'DFSDsc',
  dscmeta_module_version: '5.0.1',
  docs: 'The DSC DFSNamespaceFolder resource type.
         Automatically generated from version 5.0.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_targetstate: {
      type: "Optional[Enum['Offline', 'offline', 'Online', 'online']]",
      desc: 'Specifies the state of the DFS namespace folder target.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_referralpriorityrank: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the priority rank, as an integer, for a root target of the DFS namespace.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies if the DFS Namespace root should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_timetolivesec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a TTL interval, in seconds, for referrals.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'The description of the DFS Namespace.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_referralpriorityclass: {
      type: "Optional[Enum['Global-High', 'global-high', 'SiteCost-High', 'sitecost-high', 'SiteCost-Normal', 'sitecost-normal', 'SiteCost-Low', 'sitecost-low', 'Global-Low', 'global-low']]",
      desc: 'Specifies the target priority class for a DFS namespace root.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableinsitereferrals: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a DFS namespace server provides a client only with referrals that are in the same site as the client.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabletargetfailback: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a DFS namespace uses target failback.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: 'Optional[String]',
      desc: ' ',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Specifies a path for the root of a DFS namespace.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targetpath: {
      type: 'String',
      desc: 'Specifies a path for a root target of the DFS namespace.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
