require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dfsreplicationgroupmembership',
  dscmeta_resource_friendly_name: 'DFSReplicationGroupMembership',
  dscmeta_resource_name: 'DSC_DFSReplicationGroupMembership',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'DFSDsc',
  dscmeta_module_version: '5.0.1',
  docs: 'The DSC DFSReplicationGroupMembership resource type.
         Automatically generated from version 5.0.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_primarymember: {
      type: 'Optional[Boolean]',
      desc: 'Used to configure this as the Primary Member. Every folder must have at least one primary member for initial replication to take place.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_stagingpath: {
      type: 'Optional[String]',
      desc: 'The local staging path for the DFS Replication Group Folder.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_stagingpathquotainmb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The staging path quota size in MB for the DFS Replication Group Folder.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfsnpath: {
      type: 'Optional[String]',
      desc: 'Specify the DFS Namespace folder path of the membership. This value does not affect replication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_removedeletedfiles: {
      type: 'Optional[Boolean]',
      desc: 'Specify if a member computer deletes files and folders immediately following inbound replication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_conflictanddeletedpath: {
      type: 'Optional[String]',
      desc: 'The local content and deleted path for the DFS Replication Group Folder.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_groupname: {
      type: 'String',
      desc: 'The name of the DFS Replication Group.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_foldername: {
      type: 'String',
      desc: 'The name of the DFS Replication Group Folder.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_readonly: {
      type: 'Optional[Boolean]',
      desc: 'Specify if this content path should be read only.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_conflictanddeletedquotainmb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The local conflict and deleted path quota size in MB.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_contentpath: {
      type: 'Optional[String]',
      desc: 'The local content path for the DFS Replication Group Folder.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensureenabled: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Ensures that membership is either Enabled or Disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_computername: {
      type: 'String',
      desc: 'The computer name of the Replication Group member. This can be specified using either the ComputerName or FQDN name for the member. If an FQDN name is used and the DomainName parameter is set, the FQDN domain name must match.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'Optional[String]',
      desc: 'The name of the AD Domain the DFS Replication Group this replication group is in.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minimumfilestagingsize: {
      type: "Optional[Enum['Size256KB', 'size256kb', 'Size512KB', 'size512kb', 'Size1MB', 'size1mb', 'Size2MB', 'size2mb', 'Size4MB', 'size4mb', 'Size8MB', 'size8mb', 'Size16MB', 'size16mb', 'Size32MB', 'size32mb', 'Size64MB', 'size64mb', 'Size128MB', 'size128mb', 'Size256MB', 'size256mb', 'Size512MB', 'size512mb', 'Size1GB', 'size1gb', 'Size2GB', 'size2gb', 'Size4GB', 'size4gb', 'Size8GB', 'size8gb', 'Size16GB', 'size16gb', 'Size32GB', 'size32gb', 'Size64GB', 'size64gb', 'Size128GB', 'size128gb', 'Size256GB', 'size256gb', 'Size512GB', 'size512gb', 'Size1TB', 'size1tb', 'Size2TB', 'size2tb', 'Size4TB', 'size4tb', 'Size8TB', 'size8tb', 'Size16TB', 'size16tb', 'Size32TB', 'size32tb', 'Size64TB', 'size64tb', 'Size128TB', 'size128tb', 'Size256TB', 'size256tb', 'Size512TB', 'size512tb']]",
      desc: 'The minimum file size that DFS Replication stages during outbound replication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
